@@ -1,4 +1,4 @@
-__version__ = '20200913' #yyymmdd
+__version__ = '20210617' #yyymmdd
 __author__ = 'Robert Nikutta <robert.nikutta@gmail.com>'
 
 """Utilities for handling I/O.
@@ -31,7 +31,7 @@ def make_subcube_hdf(sourcefile='/home/robert/data/hypercat/hypercat_20181031.hd
     # copy these groups and datasets as-is
     tocopy = ['Nhypercubes','hypercubenames','pattern','rootdir','clddata']
     for _ in tocopy:
-        print("Copying ", _)
+        logging.info("Copying %s" % _)
         hs.copy(_,ht)
 
     # copy a subset of this hypercube
@@ -177,7 +177,7 @@ def save2fits(image,fitsfile,usewcs=True,extra_keywords=None):
         header['BSCALE'] = (1.00000, 'Scaling of pixel values')
         header['BZERO'] = (0.00000, 'Zero offset')
         header['BUNIT'] = (image_.data.unit.to_string(), 'Unit of image data')
-
+        
         # helper func for simple attributes
         def add2header(obj,attr,comment='',keyword=None,suffix=''):
             if hasattr(obj,attr):
